==> foundation-ui-components-1.2.0.tgz: package/src/common/dropdown/NsDropdown.tsx <==
import React, { useRef, useState } from 'react';

import { DropdownContainer, DropdownButton, DropdownList, DropdownHead } from './NsDropdown.styled';
import { NsIcon } from '../icon';
import { DropdownProps } from './types.d';
import { useOnClickOutside } from '../hooks/useOnClickOutside';

const NsDropdown: React.FC<DropdownProps> = ({
    selectedValue,
    selectedLabel,
    onSelect,
    children,
    disabled = false,
    type = 'outlined',
    placeholder = 'Select',
    dropdownBorderColor = 'accentColorB',
    closeOnMouseLeave = false,
    showListDivider = true,
}) => {
    const [isOpen, setIsOpen] = useState(false);
    const [value, setValue] = useState(selectedValue || '');
    const dropdowneRef = useRef<HTMLDivElement | null>(null);

    const handleToggle = () => {
        if (disabled) return;
        setIsOpen(!isOpen);
    };

    useOnClickOutside(dropdowneRef, handleToggle);

    const closeDropdown = () => {
        if (closeOnMouseLeave) {
            setIsOpen(false);
        }
    };

    const handleSelect = (input: string) => {
        onSelect(input);
        setIsOpen(false);
        setValue(input);
    };

    return (
        <DropdownContainer disabled={disabled} ref={dropdowneRef}>
            <DropdownHead data-testid="dropdown-head" disabled={disabled} type={type} onClick={handleToggle}>
                <DropdownButton>{selectedLabel || placeholder}</DropdownButton>
                <NsIcon testId="chevron-icon" name={isOpen ? 'arrowUp' : 'arrowDown'} color="primary" />
            </DropdownHead>
            {isOpen ? (
                <DropdownList
                    data-testid="dropdown-list"
                    onMouseLeave={closeDropdown}
                    borderColor={dropdownBorderColor}
                >
                    {React.Children.map(children, (child) => {
                        if (React.isValidElement(child)) {
                            return React.cloneElement(child, {
                                // @ts-ignore
                                onSelect: handleSelect,
                                selectedValue: value,
                                showListDivider,
                            });
                        }
                        return null;
                    })}
                </DropdownList>
            ) : null}
        </DropdownContainer>
    );
};

export default NsDropdown;

==> foundation-ui-components-1.3.0.tgz: package/src/common/dropdown/NsDropdown.tsx <==
import React, { useCallback, useRef, useState } from 'react';

import { DropdownContainer, DropdownButton, DropdownList, DropdownHead } from './NsDropdown.styled';
import { NsIcon } from '../icon';
import { DropdownProps } from './types.d';
import { useOnClickOutside } from '../hooks/useOnClickOutside';

const NsDropdown: React.FC<DropdownProps> = ({
    selectedValue,
    selectedLabel,
    onSelect,
    children,
    disabled = false,
    type = 'outlined',
    placeholder = 'Select',
    dropdownBorderColor = 'accentColorB',
    closeOnMouseLeave = false,
    showListDivider = true,
}) => {
    const [isOpen, setIsOpen] = useState(false);
    const [value, setValue] = useState(selectedValue || '');
    const dropdowneRef = useRef<HTMLDivElement | null>(null);

    const handleToggle = useCallback(() => {
        if (disabled) return;
        setIsOpen((x) => !x);
    }, [disabled]);

    const handleClose = () => {
        setIsOpen(false);
    };

    useOnClickOutside(dropdowneRef, handleClose);

    const handleOnMouseLeave = useCallback(() => {
        if (closeOnMouseLeave) {
            handleClose();
        }
    }, [closeOnMouseLeave]);

    const handleSelect = (input: string) => {
        onSelect(input);
        setIsOpen(false);
        setValue(input);
    };

    return (
        <DropdownContainer disabled={disabled} ref={dropdowneRef}>
            <DropdownHead data-testid="dropdown-head" disabled={disabled} type={type} onClick={handleToggle}>
                <DropdownButton>{selectedLabel || placeholder}</DropdownButton>
                <NsIcon testId="chevron-icon" name={isOpen ? 'arrowUp' : 'arrowDown'} color="primary" />
            </DropdownHead>
            {isOpen ? (
                <DropdownList
                    data-testid="dropdown-list"
                    onMouseLeave={handleOnMouseLeave}
                    borderColor={dropdownBorderColor}
                >
                    {React.Children.map(children, (child) => {
                        if (React.isValidElement(child)) {
                            return React.cloneElement(child, {
                                // @ts-ignore
                                onSelect: handleSelect,
                                selectedValue: value,
                                showListDivider,
                            });
                        }
                        return null;
                    })}
                </DropdownList>
            ) : null}
        </DropdownContainer>
    );
};

export default NsDropdown;
